==> viha-5.15.tar.gz: viha-5.15/jarjesto-takt.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "jarjesto";
$file = basename(__FILE__);

include "common.php";

echo "
<html>
<head>
 <title>VIHA - Jrjestjen hlytysryhmt</title>
</head>
" . body_bgcolor() . "
<h1>Jrjestt ja niiden hlytysryhmt</h1>
";

taktiset_linkit();

$jarjesto_id = get_nro_1('jarjesto_id');

$take = get_txt('take');
$release = get_txt('release');
$show = get_nro('show');

oltava_alueella($file, "jarjesto", $jarjesto_id);

if (($take != '') && saa_tehda("$file:take")) {
  $now = date('Y-m-d H:i:s');
  $where = "WHERE jarjesto_id=$jarjesto_id AND halyssa != 0";
  # asetetaan ryhma ja tila vain niilt jotka eivt ennestn kuulu thn
  # operaatioon.
  $sql =
    "UPDATE hlo
     SET ryhma_id=1,
         hlo_tila_id=3,
         ts='$now'
     $where
     AND paivystys_id != " .  s("paivystys");
  $result = my_mysql_query ($sql,true,true);
  # operaatio asetetaan kaikille hlytysryhmlisille.
  $sql =
    "UPDATE hlo
     SET paivystys_id=" . s("paivystys") . ",
         ts='$now'
     $where";
  $result = my_mysql_query ($sql,true,true);
  # varmistutaan siit, ett kaikki kuuluvat oikeaan operaatioon kuuluvaan
  # ryhmn.
  $sql =
    "UPDATE hlo
     SET ryhma_id = 1,
         ts='$now'
     $where AND ryhma_id NOT IN (SELECT id
                                 FROM ryhma
                                 WHERE paivystys_id = " . s("paivystys") . ")";
  add_hlo_ajat_sql($where);
  $sql =
    "UPDATE jarjesto
     SET paivystys_id=" . s("paivystys") . ", ts='$now'
     WHERE id=$jarjesto_id";
  $result = my_mysql_query ($sql,true,true);
  taktinen_loki("Operaatioon otettu hlytysryhm "
		. jarjesto($jarjesto_id));
  print "<p>Hlytysryhm otettu operaatioon.\n";
 }

if (($release != '') && saa_tehda("$file:take")) {
  $now = date('Y-m-d H:i:s');
  $where = "WHERE jarjesto_id=$jarjesto_id AND halyssa != 0";
  $sql =
    "UPDATE hlo
     SET ryhma_id=1, hlo_tila_id=5, ts='$now'
     $where";
  $result = my_mysql_query ($sql,true,true);
  add_hlo_ajat_sql($where);
  $sql =
    "UPDATE hlo
     SET paivystys_id=1, ts='$now'
     $where";
  $result = my_mysql_query ($sql,true,true);
  add_hlo_ajat_sql($where);
  $sql =
    "UPDATE jarjesto
     SET paivystys_id=1, ts='$now'
     WHERE id=$jarjesto_id";
  $result = my_mysql_query ($sql,true,true);
  print "<p>Hlytysryhm vapautettu operaatiosta.\n";
  taktinen_loki("Operaatiosta vapautettu hlytysryhm "
		. jarjesto($jarjesto_id));
 }

print "<form action=\"\" method=\"GET\">\n";

$sql =
  "SELECT id, jarjesto, alue_id, paivystys_id
   FROM jarjesto
   WHERE id > 2
   ORDER BY jarjesto";
$result = my_mysql_query($sql);
if ($result) {
  echo "<table border=1>" . tr_bgcolor()
	. "<th>Jrjest<th>Operaatio<th>Koko vahvuus<th>Hlytysryhmss\n";
  while ($a = mysql_fetch_array($result)) {
    if (! alue_nakyy($a['alue_id']))
      continue;
    $vahvuus =
      ota_yksi("SELECT COUNT(*)
                FROM hlo
                WHERE jarjesto_id = $a[id]");
    $halyryhmassa =
      ota_yksi("SELECT COUNT(*)
                FROM hlo
                WHERE jarjesto_id = $a[id] AND halyssa != 0");
    echo "<tr>"
      . "<TD><a href=\"jarjesto-takt-1.php?jarjesto_id=$a[id]\">$a[jarjesto]"
      . "</a>"
      . "<td>" . nayta_operaatio($a['paivystys_id'])
      . "<td>" . $vahvuus
      . "<td>" . $halyryhmassa;
    if ($a['paivystys_id'] == s('paivystys')) {
      echo "<td>"
	. "<a href=\"jarjesto-takt.php?"
	. "jarjesto_id=$a[id]&show=$show&"
	. "release=VAPAUTA\">VAPAUTA</a>\n";
    } else {
      echo "<td>"
	. "<a href=\"jarjesto-takt.php?"
	. "jarjesto_id=$a[id]&show=$show&"
	. "take=OTA\">OTA</a>\n";
    }
  }
  echo "</TABLE>\n";
} 

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: jarjesto-takt.php,v 1.21 2009/06/07 12:56:11 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/jarjesto-takt.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "jarjesto";
$file = basename(__FILE__);

include "common.php";
include "hlo-ok.php";

echo "
<html>
<head>
 <title>VIHA - Jrjestjen hlytysryhmt</title>
</head>
" . body_bgcolor() . "
<h1>Jrjestt ja niiden hlytysryhmt</h1>
";

taktiset_linkit();

$jarjesto_id = get_nro_1('jarjesto_id');

$take = get_txt('take');
$release = get_txt('release');
$show = get_nro('show');

oltava_alueella($file, "jarjesto", $jarjesto_id);

if (($release != '') && saa_tehda("$file:take")) {
  vapauta_kaikki($jarjesto_id, s("paivystys"));
 }

print "<form action=\"\" method=\"GET\">\n";

$sql =
  "SELECT id, jarjesto, alue_id, paivystys_id
   FROM jarjesto
   WHERE id > 2
   ORDER BY jarjesto";
$result = my_mysql_query($sql);
if ($result) {
  echo "<table border=1>" . tr_vaalsin()
	. "<th>Jrjest<th>Operaatio<th>Koko vahvuus<th>Hlytysryhmss\n";
  while ($a = mysql_fetch_array($result)) {
    if (! alue_nakyy($a['alue_id']))
      continue;
    $vahvuus =
      ota_yksi("SELECT COUNT(*)
                FROM hlo
                WHERE jarjesto_id = $a[id]");
    $halyryhmassa =
      ota_yksi("SELECT COUNT(*)
                FROM hlo
                WHERE jarjesto_id = $a[id]
                      AND paivystys_id = " . s("paivystys") . "
                      AND halyssa != 0");
    echo "<tr>"
      . "<TD><a href=\"jarjesto-takt-1.php?jarjesto_id=$a[id]\">$a[jarjesto]"
      . "</a>"
      . "<td>" . nayta_operaatio($a['paivystys_id'])
      . "<td>" . $vahvuus
      . "<td>" . $halyryhmassa;
    echo "<td>"
      . "<a href=\"jarjesto-takt.php?"
      . "jarjesto_id=$a[id]&show=$show&"
      . "release=VAPAUTA\">VAPAUTA</a>\n";
  }
  echo "</TABLE>\n";
} 

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: jarjesto-takt.php,v 1.25 2009/10/01 16:05:37 riku Exp $ -->
